@@ -12,6 +12,7 @@ from uuid import UUID
 
 from pydantic import Field
 
+from .._shared import EmployeeRef
 from .._shared import EngagementRef
 from .._shared import LeaveType
 from .._shared import MOBase
@@ -33,9 +34,11 @@ class LeaveBase(MOBase):
 class LeaveRead(LeaveBase):
     """A MO leave read object."""
 
-    person: UUID = Field(description="UUID of the person related to the leave.")
-    leave_type: UUID = Field(description="UUID of the leave type klasse.")
-    engagement: Optional[UUID] = Field(
+    employee_uuid: UUID = Field(
+        description="UUID of the employee related to the leave."
+    )
+    leave_type_uuid: UUID = Field(description="UUID of the leave type klasse.")
+    engagement_uuid: Optional[UUID] = Field(
         description="UUID of the engagement related to the leave."
     )
 
@@ -44,12 +47,11 @@ class LeaveWrite(LeaveBase):
     """A MO leave write object."""
 
     leave_type: LeaveType = Field(description="Reference to the leave type klasse.")
-    person: PersonRef = Field(
-        description="Reference to the person for which the leave should be created."
+    employee: EmployeeRef = Field(
+        description="Reference to the employee for which the leave should be created."
     )
     engagement: Optional[EngagementRef] = Field(
-        description="Reference to the engagement for which the leave should be "
-        "created."
+        description="Reference to the engagement for which the leave should be created."
     )
 
 
@@ -59,11 +61,11 @@ class Leave(MOBase):
     )
     leave_type: LeaveType = Field(description="Reference to the leave type facet")
     person: PersonRef = Field(
-        description="Reference to the person object for which the role should "
-        "be created."
+        description=(
+            "Reference to the person object for which the role should be created."
+        )
     )
     engagement: Optional[EngagementRef] = Field(
-        description="Reference to the engagement for which the role should "
-        "be created."
+        description="Reference to the engagement for which the role should be created."
     )
     validity: Validity = Field(description="Validity of the created role object.")
