@@ -11,6 +11,7 @@ from uuid import UUID
 
 from pydantic import Field
 
+from .._shared import EmployeeRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
@@ -32,11 +33,11 @@ class RoleBase(MOBase):
 class RoleRead(RoleBase):
     """A MO role read object."""
 
-    org_unit: UUID = Field(
+    org_unit_uuid: UUID = Field(
         description="UUID of the organisation unit related to the association."
     )
-    person: UUID = Field(description="UUID of the person related to the role.")
-    role_type: UUID = Field(description="UUID of the role type klasse.")
+    employee_uuid: UUID = Field(description="UUID of the employee related to the role.")
+    role_type_uuid: UUID = Field(description="UUID of the role type klasse.")
 
 
 class RoleWrite(RoleBase):
@@ -45,8 +46,8 @@ class RoleWrite(RoleBase):
     org_unit: OrgUnitRef = Field(
         description="Reference to the organisation unit for the role."
     )
-    person: PersonRef = Field(
-        description="Reference to the person for which the role should be created."
+    employee: EmployeeRef = Field(
+        description="Reference to the employee for which the role should be created."
     )
     role_type: RoleType = Field(description="Reference to the role type klasse.")
 
@@ -55,11 +56,13 @@ class Role(MOBase):
     type_: Literal["role"] = Field("role", alias="type", description="The object type.")
     role_type: RoleType = Field(description="Reference to the role type facet")
     person: PersonRef = Field(
-        description="Reference to the person object for which the role should "
-        "be created."
+        description=(
+            "Reference to the person object for which the role should be created."
+        )
     )
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit for which the role should "
-        "be created."
+        description=(
+            "Reference to the organisation unit for which the role should be created."
+        )
     )
     validity: Validity = Field(description="Validity of the created role object.")
